@@ -1,24 +1,25 @@
 /*
  * Copyright (C) 2006, 2007 John Costigan.
+ * Copyright (C) 2010 Alberto Mardegan <mardy@users.sourceforge.net>
  *
  * POI and GPS-Info code originally written by Cezary Jackiewicz.
  *
  * Default map data provided by http://www.openstreetmap.org/
  *
- * This file is part of Maemo Mapper.
+ * This file is part of Mappero.
  *
- * Maemo Mapper is free software: you can redistribute it and/or modify
+ * Mappero is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Maemo Mapper is distributed in the hope that it will be useful,
+ * Mappero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Maemo Mapper.  If not, see <http://www.gnu.org/licenses/>.
+ * along with Mappero.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #define _GNU_SOURCE
@@ -39,6 +40,10 @@
 #include "display.h"
 #include "dbus-ifc.h"
 
+#include <mappero/debug.h>
+
+static DBusConnection *_bus = NULL;
+
 /***********************
  * BELOW: DBUS METHODS *
  ***********************/
@@ -47,47 +52,39 @@ static gint
 dbus_ifc_cb_default(const gchar *interface, const gchar *method,
         GArray *args, gpointer data, osso_rpc_t *retval)
 {
-    printf("%s()\n", __PRETTY_FUNCTION__);
-
-    if(!strcmp(method, "top_application"))
-    {
-        g_idle_add((GSourceFunc)window_present, NULL);
-    }
+    DEBUG("%s", method);
 
+    /* TODO: study this code and figure out if this callback can be removed */
     retval->type = DBUS_TYPE_INVALID;
 
-    vprintf("%s(): return\n", __PRETTY_FUNCTION__);
     return OSSO_OK;
 }
 
 static gboolean
 dbus_ifc_set_view_position_idle(SetViewPositionArgs *args)
 {
-    Point center;
-    printf("%s(%f, %f, %d, %f)\n", __PRETTY_FUNCTION__, args->new_lat,
-            args->new_lon, args->new_zoom, args->new_viewing_angle);
+    MapPoint center;
+    DEBUG("%f, %f, %d, %f", args->new_lat, args->new_lon,
+          args->new_zoom, args->new_viewing_angle);
 
-    if(!_mouse_is_down)
     {
-        if(_center_mode > 0)
-            gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(
-                        _menu_view_ac_none_item), TRUE);
+        MapController *controller = map_controller_get_instance();
+        map_controller_disable_auto_center(controller);
 
-        latlon2unit(args->new_lat, args->new_lon, center.unitx, center.unity);
+        latlon2unit(args->new_lat, args->new_lon, center.x, center.y);
 
         map_center_unit_full(center, args->new_zoom, args->new_viewing_angle);
     }
 
     g_free(args);
 
-    vprintf("%s(): return FALSE\n", __PRETTY_FUNCTION__);
     return FALSE;
 }
 
 static gint
 dbus_ifc_handle_set_view_center(GArray *args, osso_rpc_t *retval)
 {
-    printf("%s()\n", __PRETTY_FUNCTION__);
+    DEBUG("");
     SetViewPositionArgs *svca = g_new(SetViewPositionArgs, 1);
 
     /* Argument 3: int: zoom.  Get this first because we might need it to
@@ -104,8 +101,9 @@ dbus_ifc_handle_set_view_center(GArray *args, osso_rpc_t *retval)
     if(args->len < 2)
     {
         /* Latitude and/or Longitude are not defined.  Calculate next. */
-        Point new_center = map_calc_new_center(svca->new_zoom);
-        unit2latlon(new_center.unitx, new_center.unity, svca->new_lat, svca->new_lon);
+        MapPoint new_center = map_calc_new_center(svca->new_zoom);
+        unit2latlon(new_center.x, new_center.y,
+                svca->new_lat, svca->new_lon);
     }
 
     /* Argument 1: double: latitude. */
@@ -132,13 +130,11 @@ dbus_ifc_handle_set_view_center(GArray *args, osso_rpc_t *retval)
             = (gint)(g_array_index(args, osso_rpc_t, 2).value.d + 0.5) % 360;
     }
     else
-        svca->new_viewing_angle = _center_mode > 0 && _center_rotate
-            ? _gps.heading : _next_map_rotate_angle;
+        svca->new_viewing_angle = _next_map_rotate_angle;
 
     g_idle_add((GSourceFunc)dbus_ifc_set_view_position_idle, svca);
     retval->type = DBUS_TYPE_INVALID;
 
-    vprintf("%s(): return OSSO_OK\n", __PRETTY_FUNCTION__);
     return OSSO_OK;
 }
 
@@ -146,13 +142,12 @@ static gint
 dbus_ifc_controller(const gchar *interface, const gchar *method,
         GArray *args, gpointer data, osso_rpc_t *retval)
 {
-    printf("%s(%s)\n", __PRETTY_FUNCTION__, method);
+    DEBUG("%s", method);
 
     /* Method: set_view_center */
     if(!strcmp(method, MM_DBUS_METHOD_SET_VIEW_POSITION))
         return dbus_ifc_handle_set_view_center(args, retval);
 
-    vprintf("%s(): return OSSO_ERROR\n", __PRETTY_FUNCTION__);
     return OSSO_ERROR;
 }
 
@@ -165,114 +160,54 @@ dbus_ifc_controller(const gchar *interface, const gchar *method,
  * BELOW: DBUS SIGNALS *
  ***********************/
 
-static gboolean
-dbus_ifc_view_position_changed_idle(ViewPositionChangedArgs *args)
-{
-    DBusConnection *bus = NULL;
-    DBusError error;
-    DBusMessage *message = NULL;
-    printf("%s(%f, %f, %d, %f)\n", __PRETTY_FUNCTION__, args->new_lat,
-            args->new_lon, args->new_zoom, args->new_viewing_angle);
-
-    dbus_error_init(&error);
-
-    if(NULL == (bus = dbus_bus_get(DBUS_BUS_SESSION, &error))
-            || NULL == (message = dbus_message_new_signal(MM_DBUS_PATH,
-                    MM_DBUS_INTERFACE, MM_DBUS_SIGNAL_VIEW_POSITION_CHANGED))
-            || !dbus_message_append_args(message,
-                DBUS_TYPE_DOUBLE, &args->new_lat,
-                DBUS_TYPE_DOUBLE, &args->new_lon,
-                DBUS_TYPE_INT32, &args->new_zoom,
-                DBUS_TYPE_DOUBLE, &args->new_viewing_angle,
-                DBUS_TYPE_INVALID)
-            || !dbus_connection_send(bus, message, NULL))
-    {
-        g_printerr("Error sending view_position_changed signal: %s: %s\n",
-                (dbus_error_is_set(&error)
-                 ? error.name : "<no error message>"),
-                (dbus_error_is_set(&error)
-                 ? error.message : ""));
-    }
-
-    if(message)
-        dbus_message_unref(message);
-    if(bus)
-        dbus_connection_unref(bus);
-
-    vprintf("%s(): return FALSE\n", __PRETTY_FUNCTION__);
-    return FALSE;
-}
-
 void
 dbus_ifc_fire_view_position_changed(
-        Point new_center, gint new_zoom, gdouble new_viewing_angle)
+        MapPoint new_center, gint new_zoom, gdouble new_viewing_angle)
 {
-    ViewPositionChangedArgs *args;
-    printf("%s(%d, %d, %d, %f)\n", __PRETTY_FUNCTION__, new_center.unitx,
-            new_center.unity, new_zoom, new_viewing_angle);
-
-    args = g_new(ViewPositionChangedArgs, 1);
-    unit2latlon(new_center.unitx, new_center.unity,
-            args->new_lat, args->new_lon);
-    args->new_zoom = new_zoom;
-    args->new_viewing_angle = new_viewing_angle;
-
-    g_idle_add((GSourceFunc)dbus_ifc_view_position_changed_idle, args);
-
-    vprintf("%s(): return\n", __PRETTY_FUNCTION__);
-}
-
-static gboolean
-dbus_ifc_view_dimensions_changed_idle(ViewDimensionsChangedArgs *args)
-{
-    DBusConnection *bus = NULL;
-    DBusError error;
     DBusMessage *message = NULL;
-    printf("%s(%d, %d)\n", __PRETTY_FUNCTION__,
-            args->new_view_width_pixels, args->new_view_height_pixels);
+    MapGeo new_lat, new_lon;
+    DEBUG("%d, %d, %d, %f", new_center.x, new_center.y,
+          new_zoom, new_viewing_angle);
 
-    dbus_error_init(&error);
+    unit2latlon(new_center.x, new_center.y, new_lat, new_lon);
 
-    if(NULL == (bus = dbus_bus_get(DBUS_BUS_SESSION, &error))
-            || NULL == (message = dbus_message_new_signal(MM_DBUS_PATH,
-                    MM_DBUS_INTERFACE, MM_DBUS_SIGNAL_VIEW_DIMENSIONS_CHANGED))
+    if(NULL == (message = dbus_message_new_signal(MM_DBUS_PATH,
+                    MM_DBUS_INTERFACE, MM_DBUS_SIGNAL_VIEW_POSITION_CHANGED))
             || !dbus_message_append_args(message,
-                DBUS_TYPE_INT32, &args->new_view_width_pixels,
-                DBUS_TYPE_INT32, &args->new_view_height_pixels,
+                DBUS_TYPE_DOUBLE, &new_lat,
+                DBUS_TYPE_DOUBLE, &new_lon,
+                DBUS_TYPE_INT32, &new_zoom,
+                DBUS_TYPE_DOUBLE, &new_viewing_angle,
                 DBUS_TYPE_INVALID)
-            || !dbus_connection_send(bus, message, NULL))
+            || !dbus_connection_send(_bus, message, NULL))
     {
-        g_printerr("Error sending view_dimensions_changed signal: %s: %s\n",
-                (dbus_error_is_set(&error)
-                 ? error.name : "<no error message>"),
-                (dbus_error_is_set(&error)
-                 ? error.message : ""));
+        g_printerr("Error sending view_position_changed signal.\n");
     }
 
     if(message)
         dbus_message_unref(message);
-    if(bus)
-        dbus_connection_unref(bus);
-
-    vprintf("%s(): return FALSE\n", __PRETTY_FUNCTION__);
-    return FALSE;
 }
 
 void
 dbus_ifc_fire_view_dimensions_changed(
         gint new_view_width_pixels, gint new_view_height_pixels)
 {
-    ViewDimensionsChangedArgs *args;
-    printf("%s(%d, %d)\n", __PRETTY_FUNCTION__,
-            new_view_width_pixels, new_view_height_pixels);
+    DBusMessage *message = NULL;
+    DEBUG("%d, %d", new_view_width_pixels, new_view_height_pixels);
 
-    args = g_new(ViewDimensionsChangedArgs, 1);
-    args->new_view_width_pixels = new_view_width_pixels;
-    args->new_view_height_pixels = new_view_height_pixels;
+    if(NULL == (message = dbus_message_new_signal(MM_DBUS_PATH,
+                    MM_DBUS_INTERFACE, MM_DBUS_SIGNAL_VIEW_DIMENSIONS_CHANGED))
+            || !dbus_message_append_args(message,
+                DBUS_TYPE_INT32, &new_view_width_pixels,
+                DBUS_TYPE_INT32, &new_view_height_pixels,
+                DBUS_TYPE_INVALID)
+            || !dbus_connection_send(_bus, message, NULL))
+    {
+        g_printerr("Error sending view_dimensions_changed signal.\n");
+    }
 
-    g_idle_add((GSourceFunc)dbus_ifc_view_dimensions_changed_idle, args);
-
-    vprintf("%s(): return\n", __PRETTY_FUNCTION__);
+    if(message)
+        dbus_message_unref(message);
 }
 
 /***********************
@@ -282,7 +217,7 @@ dbus_ifc_fire_view_dimensions_changed(
 void
 dbus_ifc_init()
 {
-    printf("%s()\n", __PRETTY_FUNCTION__);
+    DBusError error;
 
     if(OSSO_OK != osso_rpc_set_default_cb_f(_osso, dbus_ifc_cb_default, NULL))
         g_printerr("osso_rpc_set_default_cb_f failed.\n");
@@ -291,5 +226,13 @@ dbus_ifc_init()
                 MM_DBUS_PATH, MM_DBUS_INTERFACE, dbus_ifc_controller, NULL))
         g_printerr("osso_rpc_set_cb_f failed.\n");
 
-    vprintf("%s(): return\n", __PRETTY_FUNCTION__);
+    dbus_error_init(&error);
+    if(NULL == (_bus = dbus_bus_get(DBUS_BUS_SESSION, &error)))
+    {
+        g_printerr("Error getting session bus: %s: %s\n",
+                (dbus_error_is_set(&error)
+                 ? error.name : "<no error message>"),
+                (dbus_error_is_set(&error)
+                 ? error.message : ""));
+    }
 }
